.. _spkg_sagemath_standard_no_symbolics:

================================================================================================
sagemath_standard_no_symbolics: Sage library without the symbolics subsystem
================================================================================================

About SageMath
--------------

   "Creating a Viable Open Source Alternative to
    Magma, Maple, Mathematica, and MATLAB"

   Copyright (C) 2005-2024 The Sage Development Team

   https://www.sagemath.org

SageMath fully supports all major Linux distributions, recent versions of
macOS, and Windows (Windows Subsystem for Linux).

See https://doc.sagemath.org/html/en/installation/index.html
for general installation instructions.


About this pip-installable source distribution
----------------------------------------------

This pip-installable source distribution `sagemath-standard-no-symbolics` is a distribution of a part of the Sage Library.

Its main purpose is as a technical tool for the modularization project, to test that large parts of the Sage library are independent of the symbolics subsystem.

Type
----

standard


Dependencies
------------

- $(BLAS)
- $(MP_LIBRARY)
- $(PCFILES)
- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- $(SCRIPTS)
- :ref:`spkg_boost_cropped`
- :ref:`spkg_brial`
- :ref:`spkg_cliquer`
- :ref:`spkg_cypari`
- :ref:`spkg_cysignals`
- :ref:`spkg_cython`
- :ref:`spkg_eclib`
- :ref:`spkg_ecm`
- :ref:`spkg_flint`
- :ref:`spkg_fplll`
- :ref:`spkg_fpylll`
- :ref:`spkg_gap`
- :ref:`spkg_givaro`
- :ref:`spkg_glpk`
- :ref:`spkg_gmpy2`
- :ref:`spkg_gsl`
- :ref:`spkg_iml`
- :ref:`spkg_importlib_metadata`
- :ref:`spkg_importlib_resources`
- :ref:`spkg_jupyter_core`
- :ref:`spkg_lcalc`
- :ref:`spkg_libbraiding`
- :ref:`spkg_libgd`
- :ref:`spkg_libhomfly`
- :ref:`spkg_libpng`
- :ref:`spkg_linbox`
- :ref:`spkg_lrcalc_python`
- :ref:`spkg_m4ri`
- :ref:`spkg_m4rie`
- :ref:`spkg_memory_allocator`
- :ref:`spkg_mpc`
- :ref:`spkg_mpfi`
- :ref:`spkg_mpfr`
- :ref:`spkg_ntl`
- :ref:`spkg_numpy`
- :ref:`spkg_pari`
- :ref:`spkg_pip`
- :ref:`spkg_pkgconfig`
- :ref:`spkg_planarity`
- :ref:`spkg_ppl`
- :ref:`spkg_pplpy`
- :ref:`spkg_primecount`
- :ref:`spkg_primecountpy`
- :ref:`spkg_primesieve`
- :ref:`spkg_pythran`
- :ref:`spkg_requests`
- :ref:`spkg_rw`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_brial`
- :ref:`spkg_sagemath_combinat`
- :ref:`spkg_sagemath_eclib`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_sagemath_giac`
- :ref:`spkg_sagemath_graphs`
- :ref:`spkg_sagemath_polyhedra`
- :ref:`spkg_sagemath_repl`
- :ref:`spkg_sagemath_schemes`
- :ref:`spkg_sagemath_singular`
- :ref:`spkg_singular`
- :ref:`spkg_symmetrica`
- :ref:`spkg_typing_extensions`

Version Information
-------------------

package-version.txt::

    10.4.63

version_requirements.txt::

    passagemath-standard-no-symbolics ~= 10.4.63.0


Equivalent System Packages
--------------------------

(none known)

